# orbital-transfer
An orbital transfer corresponds to a non-coplanar orbit transfer where semi-major axis, inclination and eccentricity can be simultaneously changed. 
When considering a change in inclination, an efficiency factor is taken into account to consider the fact that this maneuver is 
less efficient away from the orbital nodes. The length of the thrust arcs about the nodes is dictated by the duty cycle. 

Different perturbations can be considered while performing this manoeuvre: Earth potential, third-body (Sun, Moon), atmospheric drag 
and solar radiation pressure. 

<b>CHANGELOG</b>
<ul>
  <li><b>2.2.0</b> - 2024-07-11 - Add space weather data source choice to <b>NRLMSISE00AtmosphericModel</b> schema</li>
  <li><b>2.1.0</b> - 2024-07-03 - Add <b>atmosphericModel</b> in <b>DragPerturbation</b> schema</li>
  <li><b>2.0.0</b> - 2024-06-06 - Complete refactoring of the API</li>
</ul>


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.2.0
- Package version: 2.2.0
- Generator version: 7.8.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import orbital_transfer
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import orbital_transfer
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import orbital_transfer
from orbital_transfer.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://orbital-transfer.exoops.57.128.40.142.sslip.io
# See configuration.py for a list of all supported configuration parameters.
configuration = orbital_transfer.Configuration(
    host = "http://orbital-transfer.exoops.57.128.40.142.sslip.io"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: BearerAuth
configuration = orbital_transfer.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with orbital_transfer.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = orbital_transfer.DefaultApi(api_client)
    analytical_orbital_transfer_request = orbital_transfer.AnalyticalOrbitalTransferRequest() # AnalyticalOrbitalTransferRequest | 

    try:
        # Analytical Orbital Transfer
        api_response = api_instance.analytical_post(analytical_orbital_transfer_request)
        print("The response of DefaultApi->analytical_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->analytical_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://orbital-transfer.exoops.57.128.40.142.sslip.io*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**analytical_post**](docs/DefaultApi.md#analytical_post) | **POST** /analytical | Analytical Orbital Transfer
*DefaultApi* | [**compute_orbital_transfer_simulation**](docs/DefaultApi.md#compute_orbital_transfer_simulation) | **POST** /simulation | Orbital transfer simulation


## Documentation For Models

 - [AdvancedOrbitParameters](docs/AdvancedOrbitParameters.md)
 - [AnalyticalOrbitalTransferRequest](docs/AnalyticalOrbitalTransferRequest.md)
 - [AnalyticalOrbitalTransferRequestDragPerturbation](docs/AnalyticalOrbitalTransferRequestDragPerturbation.md)
 - [AnalyticalOrbitalTransferResponse](docs/AnalyticalOrbitalTransferResponse.md)
 - [AtmosphericModel](docs/AtmosphericModel.md)
 - [Axis](docs/Axis.md)
 - [BodySolarArray](docs/BodySolarArray.md)
 - [BoxSpacecraftGeometry](docs/BoxSpacecraftGeometry.md)
 - [CartesianEphemerides](docs/CartesianEphemerides.md)
 - [CircularAltitudeOrbitParameters](docs/CircularAltitudeOrbitParameters.md)
 - [CircularGroundTrackRepeatedOrbitParameters](docs/CircularGroundTrackRepeatedOrbitParameters.md)
 - [CircularOrbit](docs/CircularOrbit.md)
 - [CircularOrbitParameters](docs/CircularOrbitParameters.md)
 - [CustomManeuveringStrategy](docs/CustomManeuveringStrategy.md)
 - [DeployableFixedSolarArray](docs/DeployableFixedSolarArray.md)
 - [DeployableRotatingSolarArray](docs/DeployableRotatingSolarArray.md)
 - [DragPerturbation](docs/DragPerturbation.md)
 - [DutyCycleThrustArcDefinition](docs/DutyCycleThrustArcDefinition.md)
 - [EarthPotentialPerturbation](docs/EarthPotentialPerturbation.md)
 - [EllipticalGroundTrackRepeatedEccentricityOrbitParameters](docs/EllipticalGroundTrackRepeatedEccentricityOrbitParameters.md)
 - [EllipticalOrbit](docs/EllipticalOrbit.md)
 - [EllipticalOrbitParameters](docs/EllipticalOrbitParameters.md)
 - [EllipticalPerigeeAltApogeeAltOrbitParameters](docs/EllipticalPerigeeAltApogeeAltOrbitParameters.md)
 - [EllipticalPerigeeAltEccentricityOrbitParameters](docs/EllipticalPerigeeAltEccentricityOrbitParameters.md)
 - [EllipticalSmaEccentricityOrbitParameters](docs/EllipticalSmaEccentricityOrbitParameters.md)
 - [GeostationaryOrbit](docs/GeostationaryOrbit.md)
 - [HarrisPriesterAtmosphericModel](docs/HarrisPriesterAtmosphericModel.md)
 - [KeplerianEphemerides](docs/KeplerianEphemerides.md)
 - [MeanOrOsculatingSpacecraftStates](docs/MeanOrOsculatingSpacecraftStates.md)
 - [MeanOrOsculatingSpacecraftStatesAttitude](docs/MeanOrOsculatingSpacecraftStatesAttitude.md)
 - [MeanOrOsculatingSpacecraftStatesPvCoordinates](docs/MeanOrOsculatingSpacecraftStatesPvCoordinates.md)
 - [NRLMSISE00AtmosphericModel](docs/NRLMSISE00AtmosphericModel.md)
 - [Orbit](docs/Orbit.md)
 - [OrbitalTransferSimulationRequest](docs/OrbitalTransferSimulationRequest.md)
 - [OrbitalTransferSimulationRequestInputs](docs/OrbitalTransferSimulationRequestInputs.md)
 - [OrbitalTransferSimulationRequestOutputs](docs/OrbitalTransferSimulationRequestOutputs.md)
 - [OrbitalTransferSimulationRequestOutputsOrbitalEphemerides](docs/OrbitalTransferSimulationRequestOutputsOrbitalEphemerides.md)
 - [OrbitalTransferSimulationRequestOutputsSpacecraftStates](docs/OrbitalTransferSimulationRequestOutputsSpacecraftStates.md)
 - [OrbitalTransferSimulationRequestOutputsThrustEphemerides](docs/OrbitalTransferSimulationRequestOutputsThrustEphemerides.md)
 - [OrbitalTransferSimulationResponse](docs/OrbitalTransferSimulationResponse.md)
 - [OrbitalTransferSimulationResponseFieldIndexesInner](docs/OrbitalTransferSimulationResponseFieldIndexesInner.md)
 - [OrbitalTransferSimulationResponseOrbitalEphemerides](docs/OrbitalTransferSimulationResponseOrbitalEphemerides.md)
 - [OrbitalTransferSimulationResponseOrbitalEphemeridesMean](docs/OrbitalTransferSimulationResponseOrbitalEphemeridesMean.md)
 - [OrbitalTransferSimulationResponseOrbitalEphemeridesOsculating](docs/OrbitalTransferSimulationResponseOrbitalEphemeridesOsculating.md)
 - [OrbitalTransferSimulationResponseResults](docs/OrbitalTransferSimulationResponseResults.md)
 - [OrbitalTransferSimulationResponseSpacecraftStates](docs/OrbitalTransferSimulationResponseSpacecraftStates.md)
 - [OrbitalTransferSimulationResponseSpacecraftStatesThrustingInner](docs/OrbitalTransferSimulationResponseSpacecraftStatesThrustingInner.md)
 - [OrbitalTransferSimulationResponseThrustEphemerides](docs/OrbitalTransferSimulationResponseThrustEphemerides.md)
 - [Perturbation](docs/Perturbation.md)
 - [Platform](docs/Platform.md)
 - [PropulsionSystem](docs/PropulsionSystem.md)
 - [SolarArray](docs/SolarArray.md)
 - [SolarArrayFace](docs/SolarArrayFace.md)
 - [SpacecraftGeometry](docs/SpacecraftGeometry.md)
 - [SpacecraftGeometryDimension](docs/SpacecraftGeometryDimension.md)
 - [SphericalSpacecraftGeometry](docs/SphericalSpacecraftGeometry.md)
 - [SrpPerturbation](docs/SrpPerturbation.md)
 - [ThirdBodyPerturbation](docs/ThirdBodyPerturbation.md)
 - [ThrustArcDefinition](docs/ThrustArcDefinition.md)
 - [ThrustArcsPositions](docs/ThrustArcsPositions.md)
 - [ThrustDurationThrustArcDefinition](docs/ThrustDurationThrustArcDefinition.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BearerAuth"></a>
### BearerAuth

- **Type**: Bearer authentication


## Author




